==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/MTurk/DeleteHIT.pm <==

package Paws::MTurk::DeleteHIT;
  use Moose;
  has HITId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteHIT');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MTurk::DeleteHITResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::DeleteHIT - Arguments for method DeleteHIT on Paws::MTurk

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteHIT on the 
Amazon Mechanical Turk service. Use the attributes of this class
as arguments to method DeleteHIT.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteHIT.

As an example:

  $service_obj->DeleteHIT(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> HITId => Str

The ID of the HIT to be deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteHIT in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/MTurk/DeleteHIT.pm <==

package Paws::MTurk::DeleteHIT;
  use Moose;
  has HITId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteHIT');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::MTurk::DeleteHITResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::DeleteHIT - Arguments for method DeleteHIT on L<Paws::MTurk>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteHIT on the
L<Amazon Mechanical Turk|Paws::MTurk> service. Use the attributes of this class
as arguments to method DeleteHIT.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteHIT.

=head1 SYNOPSIS

    my $mturk-requester = Paws->service('MTurk');
    my $DeleteHITResponse = $mturk -requester->DeleteHIT(
      HITId => 'MyEntityId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/mturk/>

=head1 ATTRIBUTES


=head2 B<REQUIRED> HITId => Str

The ID of the HIT to be deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteHIT in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
